:github_url: https://github.com/tasts-robots/pink/tree/master/doc/src/tasks.rst

.. _Tasks:

*****
Tasks
*****

[Until this section is written, you can check out this former version: `kinematic task <https://scaron.info/robot-locomotion/inverse-kinematics.html#kinematic-task>`_.]

Generic task
============

.. automodule:: pink.tasks.task
    :members:

Body task
=========

.. automodule:: pink.tasks.body_task
    :members:

Posture task
============

.. automodule:: pink.tasks.posture_task
    :members:
